//   Copyright (C) 2005 The Regents of the University of California.
//   All Rights Reserved.
//
//   Permission to use, copy, modify, and distribute this software and its
//   documentation for educational, research and non-profit purposes,
//   without fee, and without a written agreement is hereby granted,
//   provided that the above copyright notice, this paragraph and the
//   following three paragraphs appear in all copies.
//
//   Permission to incorporate this software into commercial products may
//   be obtained by contacting the University of California. For
//   information about obtaining such a license contact:
//
//   Chrisanna Waldrop
//   Copyright Officer
//   805-893-7773
//   waldrop@research.ucsb.edu
//
//   This software program and documentation are copyrighted by The Regents
//   of the University of California. The software program and
//   documentation are supplied "as is", without any accompanying services
//   from The Regents. The Regents does not warrant that the operation of
//   the program will be uninterrupted or error-free. The end-user
//   understands that the program was developed for research purposes and
//   is advised not to rely exclusively on the program for any reason.
//
//   IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY
//   FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES,
//   INCLUDING LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND
//   ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF CALIFORNIA HAS BEEN
//   ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. THE UNIVERSITY OF
//   CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES, INCLUDING, BUT NOT
//   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
//   A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON AN "AS IS"
//   BASIS, AND THE UNIVERSITY OF CALIFORNIA HAS NO OBLIGATIONS TO PROVIDE
//   MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
package edu.ucsb.nmsl.autocap;

import edu.ucsb.nmsl.tools.Transcript;

/**
 *
 * <p>The responsiblity of classes that implement this interface is to estimate 
 * captions that have no time-stamp after the Recognition and Alignment phases 
 * of the AutoCap process. The estimation of untime-stamped captions is 
 * important because each caption must have a time-stamp in order to create a
 * usable caption file. These estimations are based on the assumption that there 
 * are recognized segments of the media file before and after each segment
 * except for the first and last captions.</p>
 *
 * <p>Two classes implement the CaptionEstimator interface, 
 * NaiveCaptionEstimator and InterCoverageCaptionEstimator. As its name implies,
 * this technique is quite naive and very inaccurate. The NaiveCaptionEstimator 
 * is included only for research purposes because another technique, the inter-
 * coverage caption estimator technique, performs much better and creates much 
 * more accurate time stamps than this technique.
 *
 * @see edu.ucsb.nmsl.autocap.InterCoverageCaptionEstimator
 *
 * @author  Allan Knight
 * @version 1.0
 *
 */
public interface CaptionEstimator
{
  /**
   *
   * <p>This method performs the caption estimation for a given transcript. Each
   * caption of the transcript is investigate, if the first word of the caption
   * has a time-stamp, then no estimation is performed. Otherwise, the time-
   * stamp for the caption is estimated as specified in the class documentation.
   * </p>
   *
   * @param t The Transcript for which the estimation technique will be applied. 
   *
   * @return A Transcript with all captions time-stamped.
   *
   */
  public Transcript completeTranscriptTimes(Transcript t);
}
