//   Copyright (C) 2005 The Regents of the University of California.
//   All Rights Reserved.
//
//   Permission to use, copy, modify, and distribute this software and its
//   documentation for educational, research and non-profit purposes,
//   without fee, and without a written agreement is hereby granted,
//   provided that the above copyright notice, this paragraph and the
//   following three paragraphs appear in all copies.
//
//   Permission to incorporate this software into commercial products may
//   be obtained by contacting the University of California. For
//   information about obtaining such a license contact:
//
//   Chrisanna Waldrop
//   Copyright Officer
//   805-893-7773
//   waldrop@research.ucsb.edu
//
//   This software program and documentation are copyrighted by The Regents
//   of the University of California. The software program and
//   documentation are supplied "as is", without any accompanying services
//   from The Regents. The Regents does not warrant that the operation of
//   the program will be uninterrupted or error-free. The end-user
//   understands that the program was developed for research purposes and
//   is advised not to rely exclusively on the program for any reason.
//
//   IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY
//   FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES,
//   INCLUDING LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND
//   ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF CALIFORNIA HAS BEEN
//   ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. THE UNIVERSITY OF
//   CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES, INCLUDING, BUT NOT
//   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
//   A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON AN "AS IS"
//   BASIS, AND THE UNIVERSITY OF CALIFORNIA HAS NO OBLIGATIONS TO PROVIDE
//   MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
package edu.ucsb.nmsl.tools;

/**
 *
 * This class represents a statistic that represents integer information.
 * The purpose of this class is to facilitate the research associated with the
 * creation of the system and is not needed in the normal operation of
 * AutoCap. Only the displayString method is overloaded withing the definition.
 *
 * @see edu.ucsb.nmsl.tools.StatisticsPackage
 *

 * @version 1.0
 *
 */
public class IntegerStatistic extends BaseStatistic
{
  /**
   *
   * This contructor builds a IntegerStatistic instance with the name 
   * specified by "n" and with the value, as an integer, specified by i.
   *
   * @param n The name of the DoubleStatisic.
   * @param i The percentage value of the statistic.
   *

   *
   */
  public IntegerStatistic(String n, Integer i)
  {
    Name = new String(n);
    Value = i;
  }

  /**
   *
   * This contructor builds a IntegerStatistic instance with the name 
   * specified by "n" and with the value, as an integer, specified by i.
   *
   * @param n The name of the IntegerStatisic.
   * @param i The percentage value of the statistic.
   *

   *
   */
  public IntegerStatistic(String n, int i)
  {
    Name = new String(n);
    Value = new Integer(i);
  }

  /**
   *
   * This method returns a string that can be used to neatly show the 
   * statistical information associated with this particular instance. 
   *
   * @return A string representing the statistical information. This string 
   *         usually takes the form of &lt;Name&gt; = &lt;Integer&gt;
   *
   *
   */
  public String displayString()
  {
    return Name + " = " + Value.toString();
  }
}
