//   Copyright (C) 2005 The Regents of the University of California.
//   All Rights Reserved.
//
//   Permission to use, copy, modify, and distribute this software and its
//   documentation for educational, research and non-profit purposes,
//   without fee, and without a written agreement is hereby granted,
//   provided that the above copyright notice, this paragraph and the
//   following three paragraphs appear in all copies.
//
//   Permission to incorporate this software into commercial products may
//   be obtained by contacting the University of California. For
//   information about obtaining such a license contact:
//
//   Chrisanna Waldrop
//   Copyright Officer
//   805-893-7773
//   waldrop@research.ucsb.edu
//
//   This software program and documentation are copyrighted by The Regents
//   of the University of California. The software program and
//   documentation are supplied "as is", without any accompanying services
//   from The Regents. The Regents does not warrant that the operation of
//   the program will be uninterrupted or error-free. The end-user
//   understands that the program was developed for research purposes and
//   is advised not to rely exclusively on the program for any reason.
//
//   IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY
//   FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES,
//   INCLUDING LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND
//   ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF CALIFORNIA HAS BEEN
//   ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. THE UNIVERSITY OF
//   CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES, INCLUDING, BUT NOT
//   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
//   A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON AN "AS IS"
//   BASIS, AND THE UNIVERSITY OF CALIFORNIA HAS NO OBLIGATIONS TO PROVIDE
//   MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
package edu.ucsb.nmsl.tools;

/**
 *
 * This interface allows for the storage of statistical information for a 
 * specific running of AutoCap and associate a name with the information for
 * efficient retrieval and convenience when displaying the data. This 
 * convenience comes from the fact that the statistic is converted to a string
 * by prepending the name associated with the statistic to a string and the
 * the value of the Statistic instance.
 *
 * @see edu.ucsb.nmsl.tools.StatisticsPackage StatisticsPackage
 *

 * @version 1.0
 *
 */
public interface Statistic
{
  /**
   *
   * This method returns the name associated with the statistical information.
   *
   * @return The statistic name as a String.
   *

   *
   */
  public String getName();

  /**
   *
   * This method returns the value of the statistical information.
   *
   * @return The statistical information as an Object. This instance is usually
   *         one of the wrapper classes for primitive types such as Integer or
   *         Double.
   *

   *
   */
  public Object getValue();

  /**
   *
   * This method sets the name associated with the statistical information.
   *
   * @param n - The name to be associated with the statistical information.
   *

   *
   */
  public void setName(String n);

  /**
   *
   * This method sets the value of the statistical information.
   *
   * @param o - The statistical information as an Object. This instance is
   *            usually one of the wrapper classes for primitive types such as 
   *            Integer or Double.
   *

   *
   */
  public void setValue(Object o);

  /**
   * This method returns a string that can be used to neatly show the 
   * statistical information associated with a particular instance.
   *
   * @return A string representing the statistical information. This string 
   *         usually takes the form of &lt;Name&gt;: &lt;Value&gt;
   *

   *
   */
  public String displayString();
}
