//   Copyright (C) 2005 The Regents of the University of California.
//   All Rights Reserved.
//
//   Permission to use, copy, modify, and distribute this software and its
//   documentation for educational, research and non-profit purposes,
//   without fee, and without a written agreement is hereby granted,
//   provided that the above copyright notice, this paragraph and the
//   following three paragraphs appear in all copies.
//
//   Permission to incorporate this software into commercial products may
//   be obtained by contacting the University of California. For
//   information about obtaining such a license contact:
//
//   Chrisanna Waldrop
//   Copyright Officer
//   805-893-7773
//   waldrop@research.ucsb.edu
//
//   This software program and documentation are copyrighted by The Regents
//   of the University of California. The software program and
//   documentation are supplied "as is", without any accompanying services
//   from The Regents. The Regents does not warrant that the operation of
//   the program will be uninterrupted or error-free. The end-user
//   understands that the program was developed for research purposes and
//   is advised not to rely exclusively on the program for any reason.
//
//   IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY
//   FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES,
//   INCLUDING LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND
//   ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF CALIFORNIA HAS BEEN
//   ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. THE UNIVERSITY OF
//   CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES, INCLUDING, BUT NOT
//   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
//   A PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON AN "AS IS"
//   BASIS, AND THE UNIVERSITY OF CALIFORNIA HAS NO OBLIGATIONS TO PROVIDE
//   MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
package edu.ucsb.nmsl.tools;

import java.util.*;

/**
 *
 * <p>The responsibility of the StatisticsPackage is to keep the information 
 * collected during a specific running of AutoCap and allow access and print 
 * out that information as needed during research. The information collected by
 * this class is for the purposes of research only and are not necessary for the
 * normal operation of AutoCap.</p>
 *
 * <p>The Statistics class works by keeping a map of Statistic instances. This 
 * relationship names each statistic and allows for access to the information 
 * based on the name give when a Statistics instance is storeed. Also, the name
 * is used when the StatisticsPackage is converted to a string. Each statistic's
 * value is printed out along with the name used to store it in the map.</p>
 *

 * @version 1.0
 *
 */
public class StatisticsPackage
{
  /** The container that maps each Statistics object with its name. Each element
      of this container is a Statistics object and makes up the 
      StatisticsPackage */
  protected HashMap Statistics = new HashMap();

  /**
   *
   * This default constructor creates a default instance of the class.
   *

   *
   */
  public StatisticsPackage()
  {
    // This code block was intentionally left blank
  }

  /**
   *
   * This contructor creates an instance of the StatisticsPackage and fills in
   * the map with each element of the Container instance passed to the 
   * constructor. Each object is assumbed to be a child of the BaseStatistics
   * class and the name associated with the statistic is used to store it in the 
   * map.
   *
   * @param stats - A collection of BaseStatistics objects that make up the 
   * StatisticsPackage 
   *

   *
   */
  public StatisticsPackage(Collection stats) throws ClassCastException
  {
    for(Iterator i = stats.iterator(); i.hasNext();)
    {
      Object o = i.next();
      if(!(o instanceof BaseStatistic))
      {
        throw new ClassCastException();
      }

      BaseStatistic b = (BaseStatistic)o;
      Statistics.put(b.getName(), b.getValue());
    }
  }

  /**
   *
   * This function adds a BaseStatistic object to the map and expands the 
   * information stored in the package.
   *
   * @param o - The BaseStatistic instance that is being added to the package.
   *

   *
   */
  public void add(BaseStatistic o)
  {
    Statistics.put(o.getName(), o);
  }

  /**
   *
   * This function removes a BaseStatistic object from the map and contracts the 
   * information stored in the package.
   *
   * @param o - The BaseStatistic instance that is being removed from the 
   *            package.
   *

   *
   */
  public void remove(BaseStatistic o)
  {
    Statistics.remove(o.getName());
  }


  /**
   *
   * This accessor method allows the retrieval of individual BaseStatistics
   * instances from the package.
   *
   * @param name - The name of the BaseStatistic stored in the package.
   *
   * @return The instance of BaseStatistic associated with the string "name".
   *

   *
   */
  public BaseStatistic getStatistic(String name)
  {
    return (BaseStatistic)Statistics.get(name);
  }

  /**
   *
   * This method allows the user to iterator through each BaseStatistic instance
   * in the package.
   *
   * @return An Iterator instance that allows for sequential access to each 
   *         BaseStatistic within the package.
   *

   *
   */
  public Iterator iterator()
  {
    return Statistics.values().iterator();
  }

  /**
   *
   * This method allows the user to iterator through each BaseStatistic instance
   * in the package. It also allows for bidirectional access to each element.
   *
   * @return An Iterator instance that allows for sequential access to each 
   *         BaseStatistic within the package.
   *
   */
  public ListIterator listIterator(int idx)
  {
    return new LinkedList(Statistics.values()).listIterator(idx);
  }
}
